package com.medm.devicekit.sample

import android.content.Intent
import android.os.Bundle
import android.view.*
import android.widget.BaseAdapter
import android.widget.ListView
import android.widget.TextView
import android.widget.Toast
import androidx.activity.result.contract.ActivityResultContracts
import androidx.fragment.app.Fragment
import androidx.fragment.app.ListFragment
import com.medm.devicekit.*
import org.json.JSONArray

class AddedDevicesFragment : ListFragment()
{
    override fun onCreate(savedInstanceState: Bundle?)
    {
        super.onCreate(savedInstanceState)
        listAdapter = DeviceListAdapter()
    }

    override fun onResume()
    {
        super.onResume()
        (listAdapter as DeviceListAdapter).notifyDataSetChanged()
    }

    override fun onListItemClick(l: ListView, v: View, position: Int, id: Long)
    {
        super.onListItemClick(l, v, position, id)

        val device = (listAdapter as DeviceListAdapter).getDevice(position)
        val intent = Intent(activity, DeviceControlActivity::class.java)
        intent.putExtra(DeviceControlActivity.EXTRAS_DEVICE_ADDRESS, device.address)

        startActivity(intent)
    }

    private inner class DeviceListAdapter : BaseAdapter()
    {
        private var mDevices = MedMDeviceKit.getDeviceManager().devicesList.toCollection(ArrayList())

        fun getDevice(position: Int): IDeviceDescription { return mDevices[position] }

        override fun getCount(): Int { return mDevices.size }

        override fun getItem(i: Int): Any { return mDevices[i] }

        override fun getItemId(i: Int): Long { return i.toLong() }

        override fun getView(i: Int, view: View?, viewGroup: ViewGroup): View
        {
            val viewHolder: ViewHolder
            var deviceView = view

            // General ListView optimization code.
            if (deviceView == null)
            {
                deviceView = layoutInflater.inflate(R.layout.listitem_device, null)
                viewHolder = ViewHolder()
                viewHolder.deviceAddress = deviceView.findViewById(R.id.device_address)
                viewHolder.deviceName = deviceView.findViewById(R.id.device_name)
                viewHolder.deviceMeasurements = deviceView.findViewById(R.id.device_measurements)
                deviceView.tag = viewHolder
            } else
            {
                viewHolder = deviceView.tag as ViewHolder
            }

            val device = mDevices[i]
            if (device.modelName.isNotEmpty()) viewHolder.deviceName!!.text = device.modelName else viewHolder.deviceName!!.setText(R.string.unknown_device)
            viewHolder.deviceAddress!!.text = device.address
            viewHolder.deviceMeasurements!!.text = formatMeasurementTypes(device.measurementTypes)

            return deviceView!!
        }

        override fun notifyDataSetChanged()
        {
            mDevices = MedMDeviceKit.getDeviceManager().devicesList.toCollection(ArrayList())
            super.notifyDataSetChanged()
        }
    }

    internal class ViewHolder
    {
        var deviceName: TextView? = null
        var deviceAddress: TextView? = null
        var deviceMeasurements: TextView? = null
    }

    companion object
    {
        @JvmStatic
        fun formatMeasurementTypes(measurementTypes: List<MeasurementType>): String
        {
            val stypes = StringBuilder()
            for (i in measurementTypes.indices)
            {
                val type = measurementTypes[i]
                if (i > 0) stypes.append(", ")
                stypes.append(type.description)
            }
            return stypes.toString()
        }
    }
}