/*
 * Copyright (C) 2013 The Android Open Source Project, (C) 2017 MedM Global
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.medm.devicekit.sample

import android.app.Activity
import android.content.Intent
import android.os.Bundle
import android.os.Parcelable
import android.view.Menu
import android.view.MenuItem
import android.view.View
import android.widget.TextView
import androidx.appcompat.app.AppCompatActivity
import com.medm.devicekit.IDeviceDescription
import com.medm.devicekit.MedMDeviceKit

class DeviceControlActivity : AppCompatActivity()
{
    private lateinit var mDevice: IDeviceDescription

    public override fun onCreate(savedInstanceState: Bundle?)
    {
        super.onCreate(savedInstanceState)
        setContentView(R.layout.device)

        val address = intent.getStringExtra(EXTRAS_DEVICE_ADDRESS)
        mDevice = MedMDeviceKit.getDeviceManager().getDevice(address)!!

        findViewById<TextView>(R.id.device_sku).text = mDevice.sku.toString()
        findViewById<TextView>(R.id.device_name).text = mDevice.name
        findViewById<TextView>(R.id.device_address).text = address
        findViewById<TextView>(R.id.device_model_name).text = mDevice.modelName
        findViewById<TextView>(R.id.device_manufacturer).text = mDevice.manufacturer
        findViewById<TextView>(R.id.device_measurements).text = AddedDevicesFragment.formatMeasurementTypes(mDevice.measurementTypes)
        findViewById<View>(R.id.device_serial_layout).visibility = if (mDevice.serial?.isEmpty() == true) View.GONE else View.VISIBLE
        findViewById<TextView>(R.id.device_serial).text = mDevice.serial
        findViewById<View>(R.id.device_awaits_adding).visibility = if (mDevice.awaitsAdding()) View.VISIBLE else View.GONE
        supportActionBar!!.title = mDevice.name
    }

    override fun onCreateOptionsMenu(menu: Menu): Boolean
    {
        menuInflater.inflate(R.menu.device, menu)
        menu.findItem(R.id.menu_settings).isVisible = mDevice.settings.isNotEmpty()
        return true
    }

    override fun onOptionsItemSelected(item: MenuItem): Boolean
    {
        when (item.itemId)
        {
            R.id.menu_remove ->
            {
                MedMDeviceKit.getDeviceManager().removeDevice(mDevice.address)
                finish()
                return true
            }

            R.id.menu_settings ->
            {
                val intent = Intent(this, DeviceSettingsActivity::class.java)
                intent.putExtra(DeviceSettingsActivity.EXTRA_DEVICE, mDevice as Parcelable)

                startActivity(intent)
                return true
            }
        }
        return super.onOptionsItemSelected(item)
    }

    companion object
    {
        const val EXTRAS_DEVICE_ADDRESS = "DEVICE_ADDRESS"
    }
}